#!/bin/sh

ACTION=${1}
shift 1

get_image() {
  IMAGE_NAME="florider89/joplin-server:latest"
}

do_install_detail() {
  local config=`uci get joplin.@joplin[0].config_path 2>/dev/null`
  local port=`uci get joplin.@joplin[0].port 2>/dev/null`
  local IMAGE_NAME=`uci get joplin.@joplin[0].image_name 2>/dev/null`

  #Generate the generic environment variables for the docker-compose

  GEN_PASS=$(< /dev/urandom tr -dc A-Za-z0-9 2>/dev/null | head -c14; echo)
  GEN_PASS2=$(< /dev/urandom tr -dc A-Za-z0-9 2>/dev/null | head -c14; echo)
  
  # Get our local LAN IP Address
  LAN_IP=$(uci get network.lan.ipaddr)
  # Strip trailing network mask
  LAN_IP="${LAN_IP%/*}"
   
  if [ -z "$config" ]; then
      echo "config path is empty!"
      exit 1
  fi

  [ -z "$port" ] && port=22300
  [ -z "$IMAGE_NAME" ] && IMAGE_NAME=florider89/joplin-server:latest

  
  # Create Docker Compose file with custom variables
   
  # Create Docker Compose file with custom variables
touch docker-compose.yml
cat > docker-compose.yml <<EOF
version: '3'
services:
    app:
        environment:
            - APP_BASE_URL=http://${LAN_IP}:${port}
            - APP_PORT=${port}
            - POSTGRES_PASSWORD=${GEN_PASS}
            - POSTGRES_DATABASE=joplin
            - POSTGRES_USER=joplin
            - POSTGRES_PORT=5432
            - POSTGRES_HOST=db
            - DB_CLIENT=pg
        restart: unless-stopped
        image: florider89/joplin-server:latest
        ports:
            - ${port}:22300
    db:
        restart: unless-stopped
        image: postgres:13.1
        ports:
            - 5432:5432
        volumes:
            - ./data:/var/lib/postgresql/data
        environment:
            - POSTGRES_PASSWORD=${GEN_PASS}
            - POSTGRES_USER=joplin
            - POSTGRES_DB=joplin

EOF
  
  docker-compose up -d
 
  # Add a new list option to the "shortcutmenu" configuration file
  uci add shortcutmenu lists
  uci set shortcutmenu.@lists[-1].webname="$IMAGE_NAME"
  uci set shortcutmenu.@lists[-1].weburl="$LAN_IP:$port"
  uci set shortcutmenu.@lists[-1].webpath="/"
  uci commit shortcutmenu

}

usage() {
  echo "usage: $0 sub-command"
  echo "where sub-command is one of:"
  echo "      install                Install joplin"
  echo "      upgrade                Upgrade joplin"
  echo "      rm/start/stop/restart  Remove/Start/Stop/Restart joplin"
  echo "      status                 joplin status"
  echo "      port                   joplin port"
}

case ${ACTION} in
  "install")
    get_image
    do_install_detail
  ;;
  "upgrade")
    get_image
    do_install_detail
  ;;
  "rm")
    docker rm -f joplin
  ;;
  "start" | "stop" | "restart")
    docker ${ACTION} joplin
  ;;
  "status")
    docker ps --all -f 'name=joplin' --format '{{.State}}'
  ;;
  "port")
    docker ps --all -f 'name=joplin' --format '{{.Ports}}' | grep -om1 '0.0.0.0:[0-9]*' | sed 's/0.0.0.0://'
  ;;
  *)
    usage
    exit 1
  ;;
esac
